
#include <lubishev/DB.h>
#include <lubishev/Event.h>

namespace lubishev {

Event::Event(DB *db, const QString &id) : mDB(db), mID(id) { }

Event::Event(DB *db, time_t start, time_t end) : mDB(db) {
    mID = mDB->createEvent(start, end);
}

time_t Event::end() const {
    time_t t;
    mDB->eventTimes(mID, 0, &t);
    return t;
}

QString Event::id() const {
    return mID;
}

void Event::setTimes(time_t start, time_t end) {
    mDB->setEventTimes(mID, start, end);
}

void Event::setTags(const QStringList &tags) {
    mDB->setEventTags(mID, tags);
}

time_t Event::start() const {
    time_t t;
    mDB->eventTimes(mID, &t, 0);
    return t;
}

QStringList Event::tags() const {
    return mDB->eventTags(mID);
}

bool operator<(const Event &e1, const Event &e2) {
    return e1.id() < e2.id();
}

} // namespace lubishev

